From db5aa62b7faa2685f29215d4d08e13d28fd481a1 Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Mon, 15 Dec 2008 04:22:20 -0500
Subject: [PATCH] - Added a global system settings storage in ini format. - Updated the user and database prefixes to use this storage.

---
 interface/web/sites/ftp_user_edit.php |  102 +++++++++++++++++++++++++++++++++++++++++++++++---
 1 files changed, 95 insertions(+), 7 deletions(-)

diff --git a/interface/web/sites/ftp_user_edit.php b/interface/web/sites/ftp_user_edit.php
index 61f549c..2ceff9c 100644
--- a/interface/web/sites/ftp_user_edit.php
+++ b/interface/web/sites/ftp_user_edit.php
@@ -40,12 +40,10 @@
 
 require_once('../../lib/config.inc.php');
 require_once('../../lib/app.inc.php');
+require_once('tools.inc.php');
 
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'sites')) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('sites');
 
 // Loading classes
 $app->uses('tpl,tform,tform_actions');
@@ -74,8 +72,59 @@
 		
 		parent::onShowNew();
 	}
+
+	function onShowEnd() {
+		global $app, $conf, $interfaceConf;
+		/*
+		 * If the names are restricted -> remove the restriction, so that the
+		 * data can be edited
+		 */
+		
+		$app->uses('getconf');
+		$global_config = $app->getconf->get_global_config('sites');
+		$ftpuser_prefix = ($global_config['ftpuser_prefix'] == '')?'':str_replace('[CLIENTNAME]', $this->getClientName(), $global_config['ftpuser_prefix']);
+		
+		if ($this->dataRecord['username'] != ""){
+			/* REMOVE the restriction */
+			$app->tpl->setVar("username", str_replace($ftpuser_prefix , '', $this->dataRecord['username']));
+		}
+		if($_SESSION["s"]["user"]["typ"] == 'admin' || $app->auth->has_clients($_SESSION['s']['user']['userid'])) {
+			$app->tpl->setVar("username_prefix", $global_config['ftpuser_prefix']);
+		}
+		else {
+			$app->tpl->setVar("username_prefix", $ftpuser_prefix);
+		}
+
+		parent::onShowEnd();
+	}
 	
-	function onAfterInsert() {
+	function onSubmit() {
+		global $app, $conf;
+		
+		// Get the record of the parent domain
+		$parent_domain = $app->db->queryOneRecord("select * FROM web_domain WHERE domain_id = ".intval(@$this->dataRecord["parent_domain_id"]));
+		
+		// Set a few fixed values
+		$this->dataRecord["server_id"] = $parent_domain["server_id"];
+		
+		parent::onSubmit();
+	}
+	
+	function onBeforeInsert() {
+		global $app, $conf, $interfaceConf;
+		
+		$app->uses('getconf');
+		$global_config = $app->getconf->get_global_config('sites');
+		$ftpuser_prefix = ($global_config['ftpuser_prefix'] == '')?'':str_replace('[CLIENTNAME]', $this->getClientName(), $global_config['ftpuser_prefix']);
+		
+		if ($app->tform->errorMessage == '') {
+			$this->dataRecord['username'] = $ftpuser_prefix . $this->dataRecord['username'];
+		}
+		
+		parent::onBeforeInsert();
+	}
+
+		function onAfterInsert() {
 		global $app, $conf;
 		
 		$web = $app->db->queryOneRecord("SELECT * FROM web_domain WHERE domain_id = ".intval($this->dataRecord["parent_domain_id"]));
@@ -84,9 +133,30 @@
 		$uid = $web["system_user"];
 		$gid = $web["system_group"];
 		
-		$sql = "UPDATE ftp_user SET server_id = $server_id, dir = '$dir', uid = '$uid', gid = '$gid' WHERE ftp_user_id = ".$this->id;
+		// The FTP user shall be owned by the same group then the website
+		$sys_groupid = $web['sys_groupid'];
+		
+		$sql = "UPDATE ftp_user SET server_id = $server_id, dir = '$dir', uid = '$uid', gid = '$gid', sys_groupid = '$sys_groupid' WHERE ftp_user_id = ".$this->id;
 		$app->db->query($sql);
 		
+		
+	}
+
+	function onBeforeUpdate() {
+		global $app, $conf, $interfaceConf;
+
+		/*
+		 * If the names should be restricted -> do it!
+		 */
+		
+		$app->uses('getconf');
+		$global_config = $app->getconf->get_global_config('sites');
+		$ftpuser_prefix = ($global_config['ftpuser_prefix'] == '')?'':str_replace('[CLIENTNAME]', $this->getClientName(), $global_config['ftpuser_prefix']);
+		
+		/* restrict the names */
+		if ($app->tform->errorMessage == '') {
+			$this->dataRecord['username'] = $restriction . $this->dataRecord['username'];
+		}
 	}
 	
 	function onAfterUpdate() {
@@ -95,6 +165,24 @@
 		
 	}
 	
+	function getClientName() {
+		global $app, $conf;
+	
+		if($_SESSION["s"]["user"]["typ"] != 'admin') {
+			// Get the group-id of the user
+			$client_group_id = $_SESSION["s"]["user"]["default_group"];
+		} else {
+			// Get the group-id from the data itself
+			$client_group_id = $this->dataRecord['client_group_id'];
+		}
+		/* get the name of the client */
+		$tmp = $app->db->queryOneRecord("SELECT name FROM sys_group WHERE groupid = " . $client_group_id);
+		$clientName = $tmp['name'];
+		if ($clientName == "") $clientName = 'default';
+		$clientName = convertClientName($clientName);
+	
+	}
+	
 }
 
 $page = new page_action;

--
Gitblit v1.9.1